# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrapper for user-visible error exceptions to raise in the CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.core import exceptions


class FunctionsError(exceptions.Error):
  """Exceptions for Functions errors."""


class OversizedDeployment(FunctionsError):

  def __init__(self, actual_size, max_allowed_size):
    super(OversizedDeployment, self).__init__(
        'Uncompressed deployment is {}, bigger than maximum allowed size of {}.'
        .format(actual_size, max_allowed_size)
    )


class FileNotFoundError(exceptions.Error):
  """Exceptions for invalid files."""
